.. TrojanZoo documentation master file, created by
   sphinx-quickstart on Fri Dec 23 13:31:47 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

:github_url: https://github.com/ain-soph/trojanzoo

TrojanZoo documentation
===================================

TrojanZoo is a universal pytorch platform for conducting security researches (especially for backdoor attacks/defenses) for image classification in deep learning.

.. toctree::
   :maxdepth: 2
   :caption: TrojanZoo Documentation

   trojanzoo <trojanzoo/index>
   trojanvision <trojanvision/index>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
